@@ -7,13 +7,13 @@ from .storages import Dataset, RequestQueue, KeyValueStore
 
 class Scraper:
     _default_instance: Optional['Scraper'] = None
-    _config: Configuration
+    config: Configuration
 
     def __init__(self, config: Optional[Configuration] = None) -> None:
-        self._config: Configuration = config or Configuration()
-        self.dataset = Dataset(None, config=self._config)
-        self.request_queue = RequestQueue(id=None, config=self._config)
-        self.key_value_store = KeyValueStore(id=None, config=self._config)
+        self.config: Configuration = config or Configuration()
+        self.dataset = Dataset(None, config=self.config)
+        self.request_queue = RequestQueue(id=None, config=self.config)
+        self.key_value_store = KeyValueStore(id=None, config=self.config)
 
     def push_data(self, data: Any) -> None:
         if not data:
@@ -24,6 +24,7 @@ class Scraper:
 if __name__ == '__main__':
     # python -m src.beeize.scraper
     scraper = Scraper()
+    scraper.config
     """ 存储数据
     scraper.push_data({"key": "dafwew "})
     """
